function [ret,x0,str,ts,xts]=reggrad(t,x,u,flag);
%REGGRAD	is the M-file description of the SIMULINK system named REGGRAD.
%	The block-diagram can be displayed by typing: REGGRAD.
%
%	SYS=REGGRAD(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes REGGRAD to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling REGGRAD with a FLAG of zero:
%	[SIZES]=REGGRAD([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[50,84,1155,835])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '3')
set_param(sys,'Min step size', '0.001')
set_param(sys,'Max step size', '0.01')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['QUATERNIONS : ETUDE DU TANGAGE ROULIS ET LACET',13,'']])
set_param([sys,'/',['QUATERNIONS : ETUDE DU TANGAGE ROULIS ET LACET',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[490,0,495,5])

add_block('built-in/Note',[sys,'/','Stabilisation par la drive du champ magntique terrestre'])
set_param([sys,'/','Stabilisation par la drive du champ magntique terrestre'],...
		'ForeGround',5,...
		'Font Size',16,...
		'position',[478,40,483,45])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[630,715,635,720])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[495,695,500,700])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[380,720,385,725])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris',...
		'Mask Dialogue','eval(''derivdat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[825,425,1040,496])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[211,165,1077,584])
open_system([sys,'/','UnNamed1'])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport'])
set_param([sys,'/','UnNamed1/Inport'],...
		'position',[120,85,140,105])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum1'])
set_param([sys,'/','UnNamed1/Sum1'],...
		'inputs','+++',...
		'position',[555,49,595,331])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/magneto.m1'])
set_param([sys,'/','UnNamed1/magneto.m1'],...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[330,259,455,311])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain1'])
set_param([sys,'/','UnNamed1/Gain1'],...
		'position',[615,177,640,203])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[675,180,695,200])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace4'])
set_param([sys,'/','UnNamed1/To Workspace4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','quater',...
		'buffer','2500',...
		'position',[320,340,385,370])

add_block('built-in/Constant',[sys,'/','UnNamed1/Constant'])
set_param([sys,'/','UnNamed1/Constant'],...
		'Value','[0 0 0]''',...
		'position',[395,177,510,203])

add_block('built-in/Note',[sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[125,115,130,120])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'outputs','[3 4]',...
		'position',[210,255,260,375])

add_block('built-in/Note',[sys,'/','UnNamed1/Q'])
set_param([sys,'/','UnNamed1/Q'],...
		'position',[280,345,285,350])

add_block('built-in/Note',[sys,'/','UnNamed1/pqr'])
set_param([sys,'/','UnNamed1/pqr'],...
		'position',[285,250,290,255])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain'])
set_param([sys,'/','UnNamed1/Gain'],...
		'Gain','0',...
		'position',[470,82,495,108])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],'Location',[4,138,1271,744])
open_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[270,67,400,123])
add_line([sys,'/','UnNamed1'],[405,95;465,95])
add_line([sys,'/','UnNamed1'],[500,95;550,95])
add_line([sys,'/','UnNamed1'],[265,285;325,285])
add_line([sys,'/','UnNamed1'],[265,345;305,345;315,355])
add_line([sys,'/','UnNamed1'],[460,285;550,285])
add_line([sys,'/','UnNamed1'],[515,190;550,190])
add_line([sys,'/','UnNamed1'],[600,190;610,190])
add_line([sys,'/','UnNamed1'],[645,190;670,190])
add_line([sys,'/','UnNamed1'],[145,95;265,95])
add_line([sys,'/','UnNamed1'],[185,95;185,315;205,315])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[255,283,480,367])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[810,235,815,240])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[810,300,815,305])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,50,1267,977])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn1'])
set_param([sys,'/','Subsystem/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[800,452,825,478])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[905,670,910,675])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[815,621,895,659])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[705,590,710,595])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[915,624,1000,656])

add_block('built-in/Scope',[sys,'/','Subsystem/Scope3'])
set_param([sys,'/','Subsystem/Scope3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','0.000200',...
		'Hgain','50000.000000',...
		'Vmax','0.000400',...
		'Hmax','100000.000000',...
		'Window',[305,337,635,651])
set_param([sys,'/','Subsystem/Scope3'],...
		'position',[935,345,965,375])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[850,370,920,390])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn3'])
set_param([sys,'/','Subsystem/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Fcn',[sys,'/','Subsystem/Fcn'])
set_param([sys,'/','Subsystem/Fcn'],...
		'Expr','(u(1)^2+u(3)^2)^0.5',...
		'position',[720,325,760,345])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace10'])
set_param([sys,'/','Subsystem/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_tmc',...
		'buffer','points_trace',...
		'position',[790,272,890,298])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p2plusq2',...
		'buffer','points_trace',...
		'position',[805,325,875,345])

add_block('built-in/Note',[sys,'/','Subsystem/Vrifications Poinsot'])
set_param([sys,'/','Subsystem/Vrifications Poinsot'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[800,235,805,240])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[415,615,435,635])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[400,415,420,435])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,365,425,370])

add_block('built-in/Note',[sys,'/','Subsystem/reste  programmer la d"rive de B'])
set_param([sys,'/','Subsystem/reste  programmer la d"rive de B'],...
		'position',[225,225,230,230])

add_block('built-in/Note',[sys,'/','Subsystem/Reste  programmer le gradient et  le v"rifier'])
set_param([sys,'/','Subsystem/Reste  programmer le gradient et  le v"rifier'],...
		'position',[235,190,240,195])

add_block('built-in/Note',[sys,'/','Subsystem/Reste  mettre un stopn'])
set_param([sys,'/','Subsystem/Reste  mettre un stopn'],...
		'position',[205,160,210,165])

add_block('built-in/Note',[sys,'/',['Subsystem/Reste  sortir les angles',13,'',13,'']])
set_param([sys,'/',['Subsystem/Reste  sortir les angles',13,'',13,'']],...
		'position',[210,130,215,135])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To File',[sys,'/','Subsystem/To File'])
set_param([sys,'/','Subsystem/To File'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','roulis',...
		'position',[1115,377,1205,423])

add_block('built-in/To File',[sys,'/','Subsystem/To File1'])
set_param([sys,'/','Subsystem/To File1'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','tangage',...
		'position',[1115,427,1205,473])

add_block('built-in/To File',[sys,'/','Subsystem/To File2'])
set_param([sys,'/','Subsystem/To File2'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','lacet',...
		'position',[1115,482,1205,528])

add_block('built-in/To File',[sys,'/','Subsystem/To File3'])
set_param([sys,'/','Subsystem/To File3'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','temps',...
		'position',[1115,537,1205,583])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace8'])
set_param([sys,'/','Subsystem/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[970,525,1040,545])

add_block('built-in/Clock',[sys,'/','Subsystem/Clock'])
set_param([sys,'/','Subsystem/Clock'],...
		'position',[905,525,925,545])
add_line([sys,'/','Subsystem'],[525,380;740,380])
add_line([sys,'/','Subsystem'],[830,380;845,380])
add_line([sys,'/','Subsystem'],[830,380;830,360;930,360])
add_line([sys,'/','Subsystem'],[425,425;465,425])
add_line([sys,'/','Subsystem'],[525,465;695,465])
add_line([sys,'/','Subsystem'],[930,535;965,535])
add_line([sys,'/','Subsystem'],[660,380;660,335;715,335])
add_line([sys,'/','Subsystem'],[765,335;800,335])
add_line([sys,'/','Subsystem'],[660,335;660,285;785,285])
add_line([sys,'/','Subsystem'],[440,625;465,625])
add_line([sys,'/','Subsystem'],[525,580;560,580])
add_line([sys,'/','Subsystem'],[525,665;730,665])
add_line([sys,'/','Subsystem'],[675,465;675,615;730,615])
add_line([sys,'/','Subsystem'],[775,640;810,640])
add_line([sys,'/','Subsystem'],[900,640;910,640])
add_line([sys,'/','Subsystem'],[765,465;795,465])
add_line([sys,'/','Subsystem'],[830,465;855,465])
add_line([sys,'/','Subsystem'],[910,430;960,430])
add_line([sys,'/','Subsystem'],[910,465;960,465])
add_line([sys,'/','Subsystem'],[910,500;960,500])
add_line([sys,'/','Subsystem'],[945,430;945,400;1110,400])
add_line([sys,'/','Subsystem'],[943,465;945,450;1110,450])
add_line([sys,'/','Subsystem'],[945,500;945,505;1110,505])
add_line([sys,'/','Subsystem'],[930,535;930,560;1110,560])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[865,246,1060,319])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[555,257,595,533])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[600,205,605,210])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[535,440,540,445])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[540,300,545,305])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[255,413,470,517])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[585,535,590,540])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','[vp0 vq0 vr0 qt00 qt10 qt20 qt30]',...
		'position',[645,369,745,421])

add_block('built-in/Note',[sys,'/','Il manque le calcul des angles  partir du quaternion'])
set_param([sys,'/','Il manque le calcul des angles  partir du quaternion'],...
		'position',[215,105,220,110])
add_line(sys,[750,395;770,395;770,665;40,665;40,465;250,465])
add_line(sys,[600,395;640,395])
add_line(sys,[485,325;550,325])
add_line(sys,[40,475;40,325;250,325])
add_line(sys,[475,465;550,465])
add_line(sys,[770,395;770,265;860,265])
add_line(sys,[620,395;620,300;860,300])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
